==> flame-1.3.0.tar.gz: lib/components.dart <==
/// {@canonicalFor anchor.Anchor}
export 'src/anchor.dart';
export 'src/collisions/has_collision_detection.dart';
export 'src/collisions/hitboxes/screen_hitbox.dart';
export 'src/components/component.dart';
export 'src/components/component_set.dart';
export 'src/components/custom_painter_component.dart';
export 'src/components/fps_component.dart';
export 'src/components/fps_text_component.dart';
export 'src/components/input/joystick_component.dart';
export 'src/components/input/keyboard_listener_component.dart';
export 'src/components/isometric_tile_map_component.dart';
export 'src/components/mixins/component_viewport_margin.dart';
export 'src/components/mixins/draggable.dart';
export 'src/components/mixins/gesture_hitboxes.dart';
export 'src/components/mixins/has_ancestor.dart';
export 'src/components/mixins/has_decorator.dart' show HasDecorator;
export 'src/components/mixins/has_game_ref.dart';
export 'src/components/mixins/has_paint.dart';
export 'src/components/mixins/hoverable.dart';
export 'src/components/mixins/keyboard_handler.dart';
export 'src/components/mixins/parent_is_a.dart';
export 'src/components/mixins/single_child_particle.dart';
export 'src/components/mixins/tappable.dart';
export 'src/components/nine_tile_box_component.dart';
export 'src/components/parallax_component.dart';
export 'src/components/particle_system_component.dart';
export 'src/components/position_component.dart';
export 'src/components/position_type.dart';
export 'src/components/sprite_animation_component.dart';
export 'src/components/sprite_animation_group_component.dart';
export 'src/components/sprite_batch_component.dart';
export 'src/components/sprite_component.dart';
export 'src/components/sprite_group_component.dart';
export 'src/components/text_box_component.dart';
export 'src/components/text_component.dart';
export 'src/components/timer_component.dart';
export 'src/extensions/vector2.dart';
export 'src/geometry/circle_component.dart';
export 'src/geometry/polygon_component.dart';
export 'src/geometry/rectangle_component.dart';
export 'src/geometry/shape_component.dart';
export 'src/text/text_paint.dart';
export 'src/timer.dart';

==> flame-1.4.0.tar.gz: lib/components.dart <==
/// {@canonicalFor anchor.Anchor}
export 'src/anchor.dart';
export 'src/collisions/has_collision_detection.dart';
export 'src/collisions/hitboxes/screen_hitbox.dart';
export 'src/components/clip_component.dart';
export 'src/components/core/component.dart';
export 'src/components/core/component_set.dart';
export 'src/components/core/position_type.dart';
export 'src/components/custom_painter_component.dart';
export 'src/components/fps_component.dart';
export 'src/components/fps_text_component.dart';
export 'src/components/input/joystick_component.dart';
export 'src/components/input/keyboard_listener_component.dart';
export 'src/components/isometric_tile_map_component.dart';
export 'src/components/mixins/component_viewport_margin.dart';
export 'src/components/mixins/draggable.dart';
export 'src/components/mixins/gesture_hitboxes.dart';
export 'src/components/mixins/has_ancestor.dart';
export 'src/components/mixins/has_decorator.dart' show HasDecorator;
export 'src/components/mixins/has_game_ref.dart';
export 'src/components/mixins/has_paint.dart';
export 'src/components/mixins/hoverable.dart';
export 'src/components/mixins/keyboard_handler.dart';
export 'src/components/mixins/parent_is_a.dart';
export 'src/components/mixins/single_child_particle.dart';
export 'src/components/mixins/tappable.dart';
export 'src/components/nine_tile_box_component.dart';
export 'src/components/parallax_component.dart';
export 'src/components/particle_system_component.dart';
export 'src/components/position_component.dart';
export 'src/components/sprite_animation_component.dart';
export 'src/components/sprite_animation_group_component.dart';
export 'src/components/sprite_batch_component.dart';
export 'src/components/sprite_component.dart';
export 'src/components/sprite_group_component.dart';
export 'src/components/text_box_component.dart';
export 'src/components/text_component.dart';
export 'src/components/timer_component.dart';
export 'src/extensions/vector2.dart';
export 'src/geometry/circle_component.dart';
export 'src/geometry/polygon_component.dart';
export 'src/geometry/rectangle_component.dart';
export 'src/geometry/shape_component.dart';
export 'src/text/text_paint.dart';
export 'src/timer.dart';
